@@ -1,7 +1,9 @@
 """Init."""
+from bubop.arg_parser import add_bool_argument
+from bubop.classes import all_subclasses
 from bubop.cli import check_optional_mutually_exclusive, check_required_mutually_exclusive
 from bubop.common_dir import CommonDir
-from bubop.crypto import read_gpg_token
+from bubop.crypto import read_gpg_token, write_gpg_token
 from bubop.exceptions import (
     AuthenticationError,
     CliIncompatibleOptionsError,
@@ -22,7 +24,13 @@ from bubop.logging import (
 from bubop.misc import get_object_unique_name, xor
 from bubop.prefs_manager import PrefsManager
 from bubop.serial import pickle_dump, pickle_load
-from bubop.string import format_dict, format_list, non_empty
+from bubop.string import (
+    camel_case_to_dashed,
+    format_dict,
+    format_list,
+    get_random_string,
+    non_empty,
+)
 from bubop.time import format_datetime_tz, is_same_datetime, parse_datetime
 
 __all__ = [
@@ -34,11 +42,15 @@ __all__ = [
     "NotEnoughArgumentsError",
     "OperatingSystemNotSupportedError",
     "PrefsManager",
+    "add_bool_argument",
+    "all_subclasses",
+    "camel_case_to_dashed",
     "check_optional_mutually_exclusive",
     "check_required_mutually_exclusive",
     "format_datetime_tz",
     "format_dict",
     "format_list",
+    "get_random_string",
     "get_object_unique_name",
     "get_valid_filename",
     "inspect_var_name",
@@ -52,6 +64,7 @@ __all__ = [
     "pickle_dump",
     "pickle_load",
     "read_gpg_token",
+    "write_gpg_token",
     "valid_dir",
     "valid_file",
     "valid_path",
@@ -60,4 +73,4 @@ __all__ = [
     "xor",
 ]
 
-__version__ = "0.1.7"
+__version__ = "0.1.9"
