@@ -2,13 +2,13 @@
 import atexit
 import platform
 from pathlib import Path
-from typing import Any, Optional
+from typing import Any, Optional, Sequence
 
 import yaml
 
-from bubop.common_dir import CommonDir
+from bubop import common_dir
 from bubop.exceptions import OperatingSystemNotSupportedError
-from bubop.logging import logger
+from bubop.logging import logger as bubop_logger
 
 
 class PrefsManager:
@@ -20,7 +20,7 @@ class PrefsManager:
     using them as attributes: (``prefs_manager.key``)
     """
 
-    def __init__(self, app_name: str, config_fname: str = "cfg.yaml"):
+    def __init__(self, app_name: str, config_fname: str = "cfg.yaml", logger=bubop_logger):
         """Initialization method.
 
         :param app_name: Name of the application the PrefsManager is running under. This is
@@ -35,7 +35,7 @@ class PrefsManager:
         super().__init__()
 
         # sanity checks -----------------------------------------------------------------------
-        if platform.system():
+        if platform.system() not in ("Linux", "Darwin"):
             raise OperatingSystemNotSupportedError(
                 f'PrefsManager does not support current OS [{platform.system() or "UNKNOWN"}]'
             )
@@ -52,11 +52,12 @@ class PrefsManager:
                 )
 
         # initialize --------------------------------------------------------------------------
+        self._logger = logger
         self._app_name = app_name.strip()
         if self._app_name.endswith(".py"):
             self._app_name = self._app_name[:-3]
-        self._config_dir: Path = CommonDir.config() / self._app_name
-        logger.debug(f"Initialising preferences manager -> {self._config_dir}")
+        self._config_dir: Path = common_dir.CommonDir.config() / self._app_name
+        self._logger.debug(f"Initialising preferences manager -> {self._config_dir}")
         self._config_file: Path = self._config_dir / config_fname
 
         self._cleaned_up = False
@@ -68,21 +69,21 @@ class PrefsManager:
         # Load the preferences file -----------------------------------------------------------
         # If _config_dir doesn't exist this along with all the files in it should be created
         if self._config_dir.is_dir():
-            logger.info("Loading preferences...")
+            self._logger.info("Loading preferences...")
         elif self._config_dir.is_file():
             raise NotADirectoryError(self._config_dir)
         else:
-            logger.info("Creating preferences directory from scratch...")
+            self._logger.info("Creating preferences directory from scratch...")
             self._config_dir.mkdir(parents=True, exist_ok=False)
 
         if self._config_file.exists():
             with self._config_file.open("r") as f:
                 self._conts = yaml.load(f, Loader=yaml.Loader)
         else:
-            self._config_file.touch()
+            self._config_file.write_text("{}")
             self._conts = {}
 
-        atexit.register(self.cleanup)
+        atexit.register(self._cleanup)
 
     @property
     def config_directory(self) -> Path:
@@ -98,13 +99,25 @@ class PrefsManager:
         return self
 
     def __exit__(self, *_):
-        self.cleanup()
-        atexit.unregister(self.cleanup)
+        self._cleanup()
+        atexit.unregister(self._cleanup)
 
-    def len(self) -> int:
+    def __len__(self) -> int:
         """Length of the currently stored preferences."""
         return len(self._conts)
 
+    def keys(self) -> Sequence[Any]:
+        """Return the list of keys in the Preferences Manager"""
+        return list(self._conts.keys())
+
+    def values(self):
+        """Return the list of values in the Preferences Manager"""
+        return self._conts.values()
+
+    def items(self):
+        """Return the items in the Preferences Manager - similar to a dict."""
+        return self._conts.items()
+
     def empty(self) -> bool:
         """Returns whether the current preferences store is empty."""
         return len(self._conts) == 0
@@ -134,7 +147,7 @@ class PrefsManager:
             )
         self._conts[self._latest_accessed] = new_val
 
-    def cleanup(self):
+    def _cleanup(self):
         """Class destruction code."""
         if not self._cleaned_up:
             self.flush_config(self._config_file)
